#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import argparse
import sys


def main():
    text, repl, string, count = parse_args()

    occurrences = string.count(text)
    if count != -1 and occurrences != count:
        print(f'[ERROR] Expected {count} occurrences of text in string, but got {occurrences}.',
              file=sys.stderr)
        exit(1)

    string = string.replace(text, repl)

    print(string, end='')


def parse_args():
    parser = argparse.ArgumentParser(prog='py-replace')

    parser.add_argument('--text', '-t',
                        help='text to replace',
                        required=True, type=str)
    parser.add_argument('--repl', '-r',
                        help='replacement',
                        required=True, type=str)
    parser.add_argument('--count', '-c',
                        help='expected count of text in string. -1 allows any count',
                        default=1, type=int)

    args = parser.parse_args()

    string = sys.stdin.read()
    if len(string) == 0:
        print('[WARNING] The given string is empty.',
              file=sys.stderr)

    return args.text, args.repl, string, args.count


if __name__ == '__main__':
    main()
